==> jc-1.4.0.tar.gz: javax/xml/XMLConstants.h <==
// public final class javax.xml.XMLConstants

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class eb7f2a1b2ede6891 javax_xml_XMLConstants

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_XMLConstants_H_
#define _JC_javax_xml_XMLConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_xml_XMLConstants$sub_refs	_jc_javax_xml_XMLConstants$sub_refs;
typedef struct _jc_javax_xml_XMLConstants$sub_nonrefs	_jc_javax_xml_XMLConstants$sub_nonrefs;
typedef struct _jc_javax_xml_XMLConstants$refs	_jc_javax_xml_XMLConstants$refs;
typedef struct _jc_javax_xml_XMLConstants$nonrefs	_jc_javax_xml_XMLConstants$nonrefs;
typedef struct _jc_javax_xml_XMLConstants$object	_jc_javax_xml_XMLConstants$object;

typedef struct _jc_javax_xml_XMLConstants$fields_struct	_jc_javax_xml_XMLConstants$fields_struct;
typedef const struct _jc_javax_xml_XMLConstants$vmethods	_jc_javax_xml_XMLConstants$vmethods;
typedef const struct _jc_javax_xml_XMLConstants$vtable	_jc_javax_xml_XMLConstants$vtable;
typedef const struct _jc_javax_xml_XMLConstants$vtype	_jc_javax_xml_XMLConstants$vtype;

// Class fields structure
struct _jc_javax_xml_XMLConstants$fields_struct {
	struct _jc_java_lang_String$object	*DEFAULT__5fNS__5fPREFIX;
	struct _jc_java_lang_String$object	*FEATURE__5fSECURE__5fPROCESSING;
	struct _jc_java_lang_String$object	*NULL__5fNS__5fURI;
	struct _jc_java_lang_String$object	*RELAXNG__5fNS__5fURI;
	struct _jc_java_lang_String$object	*W3C__5fXML__5fSCHEMA__5fINSTANCE__5fNS__5fURI;
	struct _jc_java_lang_String$object	*W3C__5fXML__5fSCHEMA__5fNS__5fURI;
	struct _jc_java_lang_String$object	*W3C__5fXPATH__5fDATATYPE__5fNS__5fURI;
	struct _jc_java_lang_String$object	*XMLNS__5fATTRIBUTE;
	struct _jc_java_lang_String$object	*XMLNS__5fATTRIBUTE__5fNS__5fURI;
	struct _jc_java_lang_String$object	*XML__5fDTD__5fNS__5fURI;
	struct _jc_java_lang_String$object	*XML__5fNS__5fPREFIX;
	struct _jc_java_lang_String$object	*XML__5fNS__5fURI;
};
extern _jc_javax_xml_XMLConstants$fields_struct _jc_javax_xml_XMLConstants$class_fields;

// Constructors
extern void _jc_javax_xml_XMLConstants$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_XMLConstants$object *);

// Virtual methods structure
struct _jc_javax_xml_XMLConstants$vmethods {
};

// Vtable
struct _jc_javax_xml_XMLConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_XMLConstants$vmethods	javax_xml_XMLConstants;
};

// Vtype
struct _jc_javax_xml_XMLConstants$vtype {
	_jc_type			type;
	_jc_javax_xml_XMLConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_XMLConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_XMLConstants$refs {
    _jc_javax_xml_XMLConstants$sub_refs	javax_xml_XMLConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_XMLConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_XMLConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_XMLConstants$sub_nonrefs	javax_xml_XMLConstants;
};

// Object instance structure
struct _jc_javax_xml_XMLConstants$object {
	_jc_javax_xml_XMLConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_XMLConstants$vtype	*vtype;
	_jc_javax_xml_XMLConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_XMLConstants$vtype _jc_javax_xml_XMLConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_XMLConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_XMLConstants$class_object;

#endif	/* _JC_javax_xml_XMLConstants_H_ */

==> jc-1.4.6.tar.gz: javax/xml/XMLConstants.h <==
// public final class javax.xml.XMLConstants

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class eb7f2a1b2ede6891 javax_xml_XMLConstants

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_XMLConstants_H_
#define _JC_javax_xml_XMLConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_xml_XMLConstants$sub_refs	_jc_javax_xml_XMLConstants$sub_refs;
typedef struct _jc_javax_xml_XMLConstants$sub_nonrefs	_jc_javax_xml_XMLConstants$sub_nonrefs;
typedef struct _jc_javax_xml_XMLConstants$refs	_jc_javax_xml_XMLConstants$refs;
typedef struct _jc_javax_xml_XMLConstants$nonrefs	_jc_javax_xml_XMLConstants$nonrefs;
typedef struct _jc_javax_xml_XMLConstants$object	_jc_javax_xml_XMLConstants$object;

typedef struct _jc_javax_xml_XMLConstants$fields_struct	_jc_javax_xml_XMLConstants$fields_struct;
typedef const struct _jc_javax_xml_XMLConstants$vmethods	_jc_javax_xml_XMLConstants$vmethods;
typedef const struct _jc_javax_xml_XMLConstants$vtable	_jc_javax_xml_XMLConstants$vtable;
typedef const struct _jc_javax_xml_XMLConstants$vtype	_jc_javax_xml_XMLConstants$vtype;

// Class fields structure
struct _jc_javax_xml_XMLConstants$fields_struct {
	struct _jc_java_lang_String$object	*DEFAULT__5fNS__5fPREFIX;
	struct _jc_java_lang_String$object	*FEATURE__5fSECURE__5fPROCESSING;
	struct _jc_java_lang_String$object	*NULL__5fNS__5fURI;
	struct _jc_java_lang_String$object	*RELAXNG__5fNS__5fURI;
	struct _jc_java_lang_String$object	*W3C__5fXML__5fSCHEMA__5fINSTANCE__5fNS__5fURI;
	struct _jc_java_lang_String$object	*W3C__5fXML__5fSCHEMA__5fNS__5fURI;
	struct _jc_java_lang_String$object	*W3C__5fXPATH__5fDATATYPE__5fNS__5fURI;
	struct _jc_java_lang_String$object	*XMLNS__5fATTRIBUTE;
	struct _jc_java_lang_String$object	*XMLNS__5fATTRIBUTE__5fNS__5fURI;
	struct _jc_java_lang_String$object	*XML__5fDTD__5fNS__5fURI;
	struct _jc_java_lang_String$object	*XML__5fNS__5fPREFIX;
	struct _jc_java_lang_String$object	*XML__5fNS__5fURI;
};
extern _jc_javax_xml_XMLConstants$fields_struct _jc_javax_xml_XMLConstants$class_fields;

// Constructors
extern void _jc_javax_xml_XMLConstants$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_XMLConstants$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_xml_XMLConstants$vmethods {
};

// Vtable
struct _jc_javax_xml_XMLConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_XMLConstants$vmethods	javax_xml_XMLConstants;
};

// Vtype
struct _jc_javax_xml_XMLConstants$vtype {
	_jc_type			type;
	_jc_javax_xml_XMLConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_XMLConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_XMLConstants$refs {
    _jc_javax_xml_XMLConstants$sub_refs	javax_xml_XMLConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_XMLConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_XMLConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_XMLConstants$sub_nonrefs	javax_xml_XMLConstants;
};

// Object instance structure
struct _jc_javax_xml_XMLConstants$object {
	_jc_javax_xml_XMLConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_XMLConstants$vtype	*vtype;
	_jc_javax_xml_XMLConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_XMLConstants$vtype _jc_javax_xml_XMLConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_XMLConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_XMLConstants$class_object;

#endif	/* _JC_javax_xml_XMLConstants_H_ */
